Class: Openphar::Models::AHP::Monograph

Inherits:
Monograph show all
Defined in:
lib/openphar/models/ahp/monograph.rb

Overview

Base class for American Herbal Pharmacopoeia monographs.

AHP monographs carry the most extensive botanical and clinical evidence of any pharmacopoeia, including safety ratings and contraindications.

Direct Known Subclasses

Formulation, HerbalMonograph

Class Method Summary collapse

Methods inherited from Monograph

#iri, jsonld_types, #label, neo4j_labels

Methods inherited from BaseEntity

jsonld_context, neo4j_label, neo4j_labels, neo4j_labels_string, #to_cypher, #to_cypher_match, #to_jsonld, #to_neo4j_node, #to_neo4j_properties

Class Method Details

.harmonized_typeObject



25
# File 'lib/openphar/models/ahp/monograph.rb', line 25

def harmonized_type = nil

.jsonld_typeObject



26
# File 'lib/openphar/models/ahp/monograph.rb', line 26

def jsonld_type = 'AhpMonograph'

.wire_keyObject



24
# File 'lib/openphar/models/ahp/monograph.rb', line 24

def wire_key = 'monograph'