Class: Openphar::Models::API::Bhasma
- Inherits:
-
Monograph
- Object
- Lutaml::Model::Serializable
- BaseEntity
- Monograph
- Openphar::Models::API::Bhasma
- Defined in:
- lib/openphar/models/api/bhasma.rb
Overview
Bhasma — Ayurvedic processed-mineral / metal preparation.
Bhasmas are unique to Ayurvedic medicine: a mineral or metal is repeatedly calcined with herbal juices to produce an ash with therapeutic properties. Carries Rasa/Guna/Virya/Vipaka/Karma like a Dravya but with mineral-specific source + preparation method.
Class Method Summary collapse
Methods inherited from Monograph
#iri, jsonld_types, #label, neo4j_labels
Methods inherited from BaseEntity
jsonld_context, neo4j_label, neo4j_labels, neo4j_labels_string, #to_cypher, #to_cypher_match, #to_jsonld, #to_neo4j_node, #to_neo4j_properties
Class Method Details
.harmonized_type ⇒ Object
38 |
# File 'lib/openphar/models/api/bhasma.rb', line 38 def harmonized_type = 'MineralSubstance' |
.jsonld_type ⇒ Object
39 |
# File 'lib/openphar/models/api/bhasma.rb', line 39 def jsonld_type = 'ApiBhasma' |
.wire_key ⇒ Object
37 |
# File 'lib/openphar/models/api/bhasma.rb', line 37 def wire_key = 'bhasma' |