Class: Openphar::Models::THP::CannabisMonograph
- Inherits:
-
Monograph
- Object
- Lutaml::Model::Serializable
- BaseEntity
- Monograph
- Monograph
- Openphar::Models::THP::CannabisMonograph
- Defined in:
- lib/openphar/models/thp/cannabis_monograph.rb
Overview
THP-specific cannabis monograph (Thailand legalized cannabis for medical and research use in 2018; the Thai Herbal Pharmacopoeia maintains a distinct monograph type with regulatory-specific fields).
Class Method Summary collapse
Methods inherited from Monograph
#iri, jsonld_types, #label, neo4j_labels
Methods inherited from BaseEntity
jsonld_context, neo4j_label, neo4j_labels, neo4j_labels_string, #to_cypher, #to_cypher_match, #to_jsonld, #to_neo4j_node, #to_neo4j_properties
Class Method Details
.harmonized_type ⇒ Object
33 |
# File 'lib/openphar/models/thp/cannabis_monograph.rb', line 33 def harmonized_type = 'CrudeDrug' |
.jsonld_type ⇒ Object
34 |
# File 'lib/openphar/models/thp/cannabis_monograph.rb', line 34 def jsonld_type = 'ThpCannabisMonograph' |
.wire_key ⇒ Object
32 |
# File 'lib/openphar/models/thp/cannabis_monograph.rb', line 32 def wire_key = 'cannabis_monograph' |